#pragma once
#include "max.h"
#include "iparamb2.h"
#include "ClassID.h"

class IOrnaHair;

namespace Ephere { namespace Plugins { namespace Autodesk { namespace Max { namespace Ornatrix
{

//! Provides functions for manipulating Ornatrix Hair From Mesh Strips Object
class HairFromMeshStripsFPInterface : public ::FPMixinInterface
{
public:

	/** Add a hair strip object from the scene
		@param node Strip mesh object
		@return true if success
	*/
	virtual BOOL AddStripObject( INode* node ) = 0;

	/** Remove a hair strip object
		@param Index of the object from the list
		@return true if success
	*/
	virtual BOOL RemoveStripObject( int index ) = 0;

	/** Gets the function publishing interface of the hair in this object
		@return Hair interface
	*/
	virtual ::IOrnaHair* GetHairFPInterface() = 0;

	//! Use this method for retrieving this interface from an instance of a hair shells modifier
	static HairFromMeshStripsFPInterface* GetInterface( ::InterfaceServer* obj )
	{
		return static_cast<HairFromMeshStripsFPInterface*>( obj->GetInterface( ORNAHAIRFROMMESHSTRIPSOBJECT_INTERFACE ) );
	}

protected:

	enum Members
	{
		Member_AddStripObject,
		Member_RemoveStripObject,
		Member_GetHair,
	};

private:

	BEGIN_FUNCTION_MAP
		FN_1( Member_AddStripObject, TYPE_BOOL, AddStripObject, TYPE_INODE );
		FN_1( Member_RemoveStripObject, TYPE_BOOL, RemoveStripObject, TYPE_INT );
		FN_0( Member_GetHair, TYPE_INTERFACE, GetHairFPInterface );
	END_FUNCTION_MAP

};

} } } } } // Ephere::Plugins::Autodesk::Max::Ornatrix