#pragma once

// forward declared:
class Texmap;

namespace Ephere { namespace Plugins { namespace Autodesk { namespace Max { namespace Ornatrix
{

// forward declares:
class ICurve;

//! Interface to properties that specify how to render an IHair interface
class IHairRenderingProperties
{
public:

	// Properties:

	//! Gets whether this class needs to be used or ignored
	virtual bool Use() const = 0;

	//! Sets whether this class needs to be used or ignored
	virtual void Use( bool value ) = 0;

	//! Gets to which strand group these properties need to be applied. Different properties can be applied to different groups.
	virtual unsigned short StrandGroup() const = 0;

	//! Sets to which strand group these properties need to be applied
	virtual void StrandGroup( unsigned short value ) = 0;


	// Strand radius:

	//! Gets global radius to be used (or pre-multiplied) for all strands
	virtual float GlobalStrandRadius() const = 0;

	//! Sets global radius to be used (or pre-multiplied) for all strands
	virtual void GlobalStrandRadius( float value ) = 0;

	//! Gets a thickness map to be used to determine strand radius on per-strand basis, or 0 if none
	virtual ::Texmap* RadiusMap() const = 0;

	//! Sets a thickness map to be used to determine strand radius on per-strand basis, or 0 if none
	virtual void RadiusMap( ::Texmap* value ) = 0;

	//! Gets strand data channel to be used to determine strand thickness, or unsigned( -1 ) if none
	virtual unsigned RadiusStrandDataChannel() const = 0;

	//! Sets strand data channel to be used to determine strand thickness, or unsigned( -1 ) if none
	virtual void RadiusStrandDataChannel( unsigned value ) = 0;

	//! Gets a curve to determine global strand thickness on points along the strand, or 0 if none
	virtual const ICurve* RadiusCurve() const = 0;

	//! Sets a curve to determine global strand thickness on points along the strand, or 0 if none
	virtual void RadiusCurve( const ICurve* curve ) = 0;


	// Self shadowing:

	//! Gets whether self-shadowing is used
	virtual bool UsesSelfShadowing() const = 0;

	//! Sets whether self-shadowing is used
	virtual void UsesSelfShadowing( bool value ) = 0;

	//! Gets self-shadowing coefficient
	virtual float SelfShadowingCoefficient() const = 0;

	//! Sets self-shadowing coefficient
	virtual void SelfShadowingCoefficient( float value ) = 0;
};

} } } } } // Ephere::Plugins::Autodesk::Max::Ornatrix