#pragma once
#include "max.h"
#include "iparamb2.h"
#include "ClassID.h"

namespace Ephere { namespace Plugins { namespace Autodesk { namespace Max { namespace Ornatrix
{

//! Provides functions for manipulating Ornatrix Surface Comb modifier
class SurfaceCombModifierFPInterface : public ::FPMixinInterface
{
public:

	//! Begins new sink creation inside the GUI.
	virtual void CreateSink() = 0;

	/** Adds a new sink.
		The sink is appended at the end of the current sink array.
		@return The index of the addedsink.
	*/
	virtual int AddSink() = 0;

	/** Deletes the specified sink.
		@param sinkIndex The index of the sink to be deleted.
	*/
	virtual void DeleteSink( int sinkIndex ) = 0;

	//! Deletes currently selected sinks
	virtual void DeleteSelSinks() = 0;

	/** Creates a new sink on distribution mesh surface on the specified face and at specified barycentric coordinate.
		@param type The type of sink to create. Can be repel, attract, or direct, respectively.
		@param vector The vector direction component of the sink.
		@param faceIndex The index of face on distribution mesh where to place the sink.
		@param barycentricCoordinate Barycentric coordinate on the face for the location of the sink.
	*/
	virtual void CreateSinkAtCoordinate( int type, ::Point3 direction, int faceIndex, ::Point3 barycentricCoordinate ) = 0;

	/** Gets the number of sinks currently in this modifier.
		@return Sink count
	*/
	virtual int GetSinkCount() = 0;

	/** Gets whether specified sink is currently selected.
		@param index Index of the sink
		@return true if sink is selected
	*/
	virtual BOOL IsSinkSelected( int index ) = 0;

	/** Sets the strength of the specified sink.
		@param index Index of the sink, or -1 to affect all selected sinks.
		@param value New strength value for the sink.
	*/
	virtual void SetSinkStrength( int index, float value ) = 0;

	/** Sets the type of the specified sink.
		@param index Index of the sink, or -1 to affect all selected sinks.
		@param type New type value for the sink.
	*/
	virtual void SetSinkType( int index, int type ) = 0;

	//! Use this method for retrieving this interface from an instance of a surface comb modifier
	static SurfaceCombModifierFPInterface* GetInterface( ::InterfaceServer* obj )
	{
		return static_cast<SurfaceCombModifierFPInterface*>( obj->GetInterface( ORNASURFCOMB_INTERFACE ) );
	}

protected:

	enum Members
	{
		Member_CreateSink,
		Member_AddSink,
		Member_DeleteSink,
		Member_DeleteSelectedSinks,
		Member_CreateSinkAtCoordinate,
		Member_GetSinkCount,
		Member_IsSinkSelected,
		Member_SetSinkStrength,
		Member_SetSinkType
	};

private:

	BEGIN_FUNCTION_MAP
		VFN_0( Member_CreateSink, CreateSink );
		FN_0( Member_AddSink, TYPE_INT, AddSink );
		VFN_1( Member_DeleteSink, DeleteSink, TYPE_INT );
		VFN_0( Member_DeleteSelectedSinks, DeleteSelSinks );
		VFN_4( Member_CreateSinkAtCoordinate, CreateSinkAtCoordinate, TYPE_INT, TYPE_POINT3, TYPE_INT, TYPE_POINT3 );
		FN_0( Member_GetSinkCount, TYPE_INT, GetSinkCount );
		FN_1( Member_IsSinkSelected, TYPE_BOOL, IsSinkSelected, TYPE_INT );
		VFN_2( Member_SetSinkStrength, SetSinkStrength, TYPE_INT, TYPE_FLOAT );
		VFN_2( Member_SetSinkType, SetSinkType, TYPE_INT, TYPE_INT );
	END_FUNCTION_MAP

};

} } } } } // Ephere::Plugins::Autodesk::Max::Ornatrix